engine.Field

Saved parameters which can generate lucene Fields given values.

Usage

engine.Field()

Parameters

name

name of field

Attributes

Name Description
settings dict representation of settings

settings

dict representation of settings

settings: dict

Methods

Name Description
String() Return Field with default settings for strings.
Text() Return Field with default settings for text.
items() Generate lucene Fields suitable for adding to a document.

String()

Return Field with default settings for strings.

Usage

String(name, tokenized=False, omitNorms=True, indexOptions="DOCS", **settings)

Text()

Return Field with default settings for text.

Usage

Text(name, indexOptions="DOCS_AND_FREQS_AND_POSITIONS", **settings)

items()

Generate lucene Fields suitable for adding to a document.

Usage

items(*values)